Class: Hash
- Inherits:
-
Object
- Object
- Hash
- Defined in:
- lib/unbind/core_ext/hash/keys.rb
Overview
grabbed from activesupport-4.0.1
Instance Method Summary collapse
-
#assert_valid_keys(*valid_keys) ⇒ Object
Validate all keys in a hash match
*valid_keys, raising ArgumentError on a mismatch. -
#deep_stringify_keys ⇒ Object
Return a new hash with all keys converted to strings.
-
#deep_stringify_keys! ⇒ Object
Destructively convert all keys to strings.
-
#deep_symbolize_keys ⇒ Object
Return a new hash with all keys converted to symbols, as long as they respond to
to_sym. -
#deep_symbolize_keys! ⇒ Object
Destructively convert all keys to symbols, as long as they respond to
to_sym. -
#deep_transform_keys(&block) ⇒ Object
Return a new hash with all keys converted by the block operation.
-
#deep_transform_keys!(&block) ⇒ Object
Destructively convert all keys by using the block operation.
-
#stringify_keys ⇒ Object
Return a new hash with all keys converted to strings.
-
#stringify_keys! ⇒ Object
Destructively convert all keys to strings.
-
#symbolize_keys ⇒ Object
(also: #to_options)
Return a new hash with all keys converted to symbols, as long as they respond to
to_sym. -
#symbolize_keys! ⇒ Object
(also: #to_options!)
Destructively convert all keys to symbols, as long as they respond to
to_sym. -
#transform_keys ⇒ Object
Return a new hash with all keys converted using the block operation.
-
#transform_keys! ⇒ Object
Destructively convert all keys using the block operations.
Instance Method Details
#assert_valid_keys(*valid_keys) ⇒ Object
Validate all keys in a hash match *valid_keys, raising ArgumentError on a mismatch. Note that keys are NOT treated indifferently, meaning if you use strings for keys but assert symbols as keys, this will fail.
{ name: 'Rob', years: '28' }.assert_valid_keys(:name, :age) # => raises "ArgumentError: Unknown key: years"
{ name: 'Rob', age: '28' }.assert_valid_keys('name', 'age') # => raises "ArgumentError: Unknown key: name"
{ name: 'Rob', age: '28' }.assert_valid_keys(:name, :age) # => passes, raises nothing
69 70 71 72 73 74 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 69 def assert_valid_keys(*valid_keys) valid_keys.flatten! each_key do |k| raise ArgumentError.new("Unknown key: #{k}") unless valid_keys.include?(k) end end |
#deep_stringify_keys ⇒ Object
Return a new hash with all keys converted to strings. This includes the keys from the root hash and from all nested hashes.
hash = { person: { name: 'Rob', age: '28' } }
hash.deep_stringify_keys
# => { "person" => { "name" => "Rob", "age" => "28" } }
111 112 113 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 111 def deep_stringify_keys deep_transform_keys{ |key| key.to_s } end |
#deep_stringify_keys! ⇒ Object
Destructively convert all keys to strings. This includes the keys from the root hash and from all nested hashes.
118 119 120 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 118 def deep_stringify_keys! deep_transform_keys!{ |key| key.to_s } end |
#deep_symbolize_keys ⇒ Object
Return a new hash with all keys converted to symbols, as long as they respond to to_sym. This includes the keys from the root hash and from all nested hashes.
hash = { 'person' => { 'name' => 'Rob', 'age' => '28' } }
hash.deep_symbolize_keys
# => { person: { name: "Rob", age: "28" } }
130 131 132 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 130 def deep_symbolize_keys deep_transform_keys{ |key| key.to_sym rescue key } end |
#deep_symbolize_keys! ⇒ Object
Destructively convert all keys to symbols, as long as they respond to to_sym. This includes the keys from the root hash and from all nested hashes.
137 138 139 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 137 def deep_symbolize_keys! deep_transform_keys!{ |key| key.to_sym rescue key } end |
#deep_transform_keys(&block) ⇒ Object
Return a new hash with all keys converted by the block operation. This includes the keys from the root hash and from all nested hashes.
hash = { person: { name: 'Rob', age: '28' } }
hash.deep_transform_keys{ |key| key.to_s.upcase }
# => { "PERSON" => { "NAME" => "Rob", "AGE" => "28" } }
84 85 86 87 88 89 90 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 84 def deep_transform_keys(&block) result = {} each do |key, value| result[yield(key)] = value.is_a?(Hash) ? value.deep_transform_keys(&block) : value end result end |
#deep_transform_keys!(&block) ⇒ Object
Destructively convert all keys by using the block operation. This includes the keys from the root hash and from all nested hashes.
95 96 97 98 99 100 101 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 95 def deep_transform_keys!(&block) keys.each do |key| value = delete(key) self[yield(key)] = value.is_a?(Hash) ? value.deep_transform_keys!(&block) : value end self end |
#stringify_keys ⇒ Object
Return a new hash with all keys converted to strings.
hash = { name: 'Rob', age: '28' }
hash.stringify_keys
#=> { "name" => "Rob", "age" => "28" }
33 34 35 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 33 def stringify_keys transform_keys{ |key| key.to_s } end |
#stringify_keys! ⇒ Object
Destructively convert all keys to strings. Same as stringify_keys, but modifies self.
39 40 41 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 39 def stringify_keys! transform_keys!{ |key| key.to_s } end |
#symbolize_keys ⇒ Object Also known as: to_options
Return a new hash with all keys converted to symbols, as long as they respond to to_sym.
hash = { 'name' => 'Rob', 'age' => '28' }
hash.symbolize_keys
#=> { name: "Rob", age: "28" }
50 51 52 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 50 def symbolize_keys transform_keys{ |key| key.to_sym rescue key } end |
#symbolize_keys! ⇒ Object Also known as: to_options!
Destructively convert all keys to symbols, as long as they respond to to_sym. Same as symbolize_keys, but modifies self.
57 58 59 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 57 def symbolize_keys! transform_keys!{ |key| key.to_sym rescue key } end |
#transform_keys ⇒ Object
Return a new hash with all keys converted using the block operation.
hash = { name: 'Rob', age: '28' }
hash.transform_keys{ |key| key.to_s.upcase }
# => { "NAME" => "Rob", "AGE" => "28" }
10 11 12 13 14 15 16 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 10 def transform_keys result = {} each_key do |key| result[yield(key)] = self[key] end result end |
#transform_keys! ⇒ Object
Destructively convert all keys using the block operations. Same as transform_keys but modifies self.
20 21 22 23 24 25 |
# File 'lib/unbind/core_ext/hash/keys.rb', line 20 def transform_keys! keys.each do |key| self[yield(key)] = delete(key) end self end |